package com.caimei365.order.components;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import okhttp3.FormBody;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

import java.io.IOException;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author zzj
 */

@Slf4j
public class OnlinePostFormUtil {

    public static OkHttpClient client = new OkHttpClient.Builder()
            .connectTimeout(3, TimeUnit.SECONDS)
            .readTimeout(20, TimeUnit.SECONDS)
            .build();

    public static <T> T postForm(Map<String, String> params, String url, String sign, Class<T> clazz) {
        FormBody.Builder builder = new FormBody.Builder();
        for (Map.Entry<String, String> entry : params.entrySet()) {
            builder.add(entry.getKey(), entry.getValue());
        }
        builder.add("sign", sign);

        Request request = new Request.Builder() // okHttp post
                .url(url)
                .post(builder.build())
                .build();

        Response response = null;
        try {
            response = client.newCall(request).execute();
        } catch (IOException e) {
            throw new IllegalStateException("请求出错", e);
        }
        if (!response.isSuccessful()) {
            try {
                log.info(response.body().string());
            } catch (IOException e) {
                e.printStackTrace();
            }
            throw new RuntimeException("请求失败了: http response code: " + response.code());
        }

        okhttp3.ResponseBody body = response.body();
        String content = null;
        try {
            content = body.string();
        } catch (IOException e) {
            throw new IllegalStateException("IO异常", e);
        }
        JSONObject res = JSON.parseObject(content);
        //网银查询回调
        if (!"SUCCESS".equals(res.getString("rt10_orderStatus"))) {
            log.info("网银查询成功结果------->"+res.toString());
        }
        /** rt4_success 为 true，需验签  **/
        return res.toJavaObject(clazz);
    }

}
